stalker.core.models.Sequence
============================

.. inheritance-diagram::
     stalker.core.models.Sequence
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: Sequence
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Sequence.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Sequence.code
      ~Sequence.created_by
      ~Sequence.date_created
      ~Sequence.date_updated
      ~Sequence.description
      ~Sequence.due_date
      ~Sequence.duration
      ~Sequence.lead
      ~Sequence.name
      ~Sequence.nice_name
      ~Sequence.notes
      ~Sequence.project
      ~Sequence.references
      ~Sequence.shots
      ~Sequence.start_date
      ~Sequence.status
      ~Sequence.status_list
      ~Sequence.tags
      ~Sequence.tasks
      ~Sequence.type
      ~Sequence.updated_by
   
   